[Scummvm-cvs-logs] scummvm master -> 49c76c835bf000622bd5b078ef87275a335934fa

bluegr md5 at scummvm.org
Mon Jul 16 11:12:11 CEST 2012


This automated email contains information about 1 new commit which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
49c76c835b SCI: Only skip text in room 100 in the SQ6 demo


Commit: 49c76c835bf000622bd5b078ef87275a335934fa
    https://github.com/scummvm/scummvm/commit/49c76c835bf000622bd5b078ef87275a335934fa
Author: Filippos Karapetis (md5 at scummvm.org)
Date: 2012-07-16T02:11:22-07:00

Commit Message:
SCI: Only skip text in room 100 in the SQ6 demo

Changed paths:
    engines/sci/engine/kgraphics32.cpp



diff --git a/engines/sci/engine/kgraphics32.cpp b/engines/sci/engine/kgraphics32.cpp
index f0989f5..093920e 100644
--- a/engines/sci/engine/kgraphics32.cpp
+++ b/engines/sci/engine/kgraphics32.cpp
@@ -173,9 +173,9 @@ reg_t kCreateTextBitmap(EngineState *s, int argc, reg_t *argv) {
 		debugC(kDebugLevelStrings, "%s", text.c_str());
 		uint16 maxWidth = argv[1].toUint16();	// nsRight - nsLeft + 1
 		uint16 maxHeight = argv[2].toUint16();	// nsBottom - nsTop + 1
-		// These values can be larger than the screen in the SQ6 demo
-		// TODO: Find out why. For now, don't show any text in the SQ6 demo.
-		if (g_sci->getGameId() == GID_SQ6 && g_sci->isDemo())
+		// These values can be larger than the screen in the SQ6 demo, room 100
+		// TODO: Find out why. For now, don't show any text in that room.
+		if (g_sci->getGameId() == GID_SQ6 && g_sci->isDemo() && s->currentRoomNumber() == 100)
 			return NULL_REG;
 		return g_sci->_gfxText32->createTextBitmap(object, maxWidth, maxHeight);
 	}






More information about the Scummvm-git-logs mailing list